===========
Information
===========

This libary can helps you to replace parts of your django project.

to make your content replacement as comfortable as possible the library offers you

 * django: templatetags
 * django: mixins
 * js/npm: js libary

With these options its very easy to replace parts of your project.


Limitations
===========

 * This libary doesnt work with functional based views
 * This libary doesnt handle submits from partitial forms (but you can just upgrade this)


Recommend
=========

You can use webpack to build your own js files. just simply use `npm install django-partitialajax`
